@@ -3,12 +3,13 @@ import enum
 
 class Predicate(str, enum.Enum):
     """Relations for constraint specification."""
-    NONNEGATIVE = 'nonnegative'
-    POSITIVE = 'positive'
-    NONPOSITIVE = 'nonpositive'
-    NEGATIVE = 'negative'
-    ZERO = 'zero'
-    NONZERO = 'nonzero'
+
+    NONNEGATIVE = "nonnegative"
+    POSITIVE = "positive"
+    NONPOSITIVE = "nonpositive"
+    NEGATIVE = "negative"
+    ZERO = "zero"
+    NONZERO = "nonzero"
 
     def __repr__(self):
-        return str(self).__str__()
\ No newline at end of file
+        return str(self).__str__()
